:mod:`qt_binder.type_registry`
==============================

.. currentmodule:: qt_binder.type_registry

.. autoclass:: TypeRegistry
    :members:
    :show-inheritance:

----

.. autoclass:: LazyRegistry
    :members:
    :show-inheritance:

